@@ -1,6 +1,6 @@
 from django.contrib import admin
 
-from .models import TaskBuild
+from .models import TaskBuild, VersionBuild
 
 
 class TaskBuildAdmin(admin.ModelAdmin):
@@ -9,3 +9,4 @@ class TaskBuildAdmin(admin.ModelAdmin):
 
 
 admin.site.register(TaskBuild, TaskBuildAdmin)
+admin.site.register(VersionBuild)
