@@ -39,6 +39,7 @@ AccordionEntry = get_class('cms.blocks.entries', 'AccordionEntry')
 FormEntry = get_class('cms.blocks.entries', 'FormEntry')
 PortfoliosEntry = get_class('cms.blocks.entries', 'PortfoliosEntry')
 GalleryEntry = get_class('cms.blocks.entries', 'GalleryEntry')
+StreamContentEntry = get_class('cms.blocks.entries', 'StreamContentEntry')
 
 
 
@@ -139,6 +140,7 @@ class AGenericPage(Page):
         ('form', FormEntry()),
         ('portfolios', PortfoliosEntry()),
         ('gallery', GalleryEntry()),
+        ('stream_content', StreamContentEntry())
     ], blank=True)
 
     content_panels = [
