@@ -242,6 +242,27 @@ const Animation = {
   },
 };
 
+const BgSlide = {
+  init: () => {
+    const io = new IntersectionObserver(entries => entries.forEach((item) => {
+      const element = item.target;
+      if (item.isIntersecting) {
+        for (let i = 0; i < element.children.length; i++) {
+          const child = element.children[i];
+          if (child.getAttribute('data-src')) {
+            setTimeout(() => {
+              child.style.backgroundImage = `url(${child.dataset.src})`;
+              child.classList.add('anim');
+            }, 4500 * i);
+          }
+        }
+        io.unobserve(element);
+      }
+    }));
+    document.querySelectorAll('.bg-container').forEach(element => io.observe(element));
+  },
+};
+
 export default {
   Image,
   Carousel,
@@ -253,4 +274,5 @@ export default {
   Accordion,
   CounterUp,
   Animation,
+  BgSlide,
 };
